Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WaitForTestDial ¶ added in v0.12.2
WaitForTestDial tries to create a client connection to the given target with a blocking dial and a timeout specified in testDialTimeout. Nothing is done with the connection, which is just closed in case it is created.
Types ¶
type Checker ¶
type Checker struct {
// contains filtered or unexported fields
}
Checker is responsible for running health checks and serving the healthcheck HTTP paths
func NewChecker ¶
func NewChecker(config Config, log logrus.FieldLogger) *Checker
type Config ¶
type Config struct {
ListenerEnabled bool `hcl:"listener_enabled"`
// Address and port to listen on, defaulting to localhost:80
BindAddress string `hcl:"bind_address"`
BindPort string `hcl:"bind_port"`
// Paths for /ready and /live
ReadyPath string `hcl:"ready_path"`
LivePath string `hcl:"live_path"`
UnusedKeys []string `hcl:",unusedKeys"`
}
Click to show internal directories.
Click to hide internal directories.